@@ -37,14 +37,14 @@ Example
     import schunk
     import serial
 
-    mod = schunk.Module(schunk.RS232Connection(
+    mod = schunk.Module(schunk.SerialConnection(
         0x0B, serial.Serial, port=0, baudrate=9600, timeout=1))
 
     mod.move_pos(42)
 
 """
 
-__version__ = "0.1.3"
+__version__ = "0.2.0"
 
 import struct
 import contextlib
@@ -72,7 +72,7 @@ class Module:
             into account) and yield the response (and further messages)
             as a bytes object.
 
-            :class:`RS232Connection` happens to do exactly that.
+            :class:`SerialConnection` happens to do exactly that.
 
         """
         self._connection = connection
@@ -340,7 +340,7 @@ class Module:
 
         module_id : int (1..255)
         group_id : int (1..255)
-        rs232_baudrate : int (1200, 2400, 4800, 9600, 19200, 38400)
+        serial_baudrate : int (1200, 2400, 4800, 9600, 19200, 38400)
         can_baudrate : int (50, 100, 125, 250, 500, 800, 1000)
 
         communication_mode : int
@@ -615,7 +615,7 @@ class _Config:
     _params = {
         'module_id':          (b'\x01', 'B'),
         'group_id':           (b'\x02', 'B'),
-        'rs232_baudrate':     (b'\x03', 'H'),
+        'serial_baudrate':    (b'\x03', 'H'),
         'can_baudrate':       (b'\x04', 'H'),
         'communication_mode': (b'\x05', 'B'),
         'unit_system':        (b'\x06', 'B'),
@@ -635,14 +635,15 @@ class _Config:
         'gear_ratio':         (b'\x18', 'f'),
         'eeprom':             (b'\xFE', None),
 
-        'module_type':        (None, '8s4x2x2x2x26x'),
+        'module_type':        (None, '8s4x2x2x2x21x5x'),
         # 'order_number' is already available
-        'firmware_version':   (None, '8x4xH2x2x26x'),
-        'protocol_version':   (None, '8x4x2xH2x26x'),
-        'hardware_version':   (None, '8x4x2x2xH26x'),
-        # Note: the Schunk manual states that the date string has 21 bytes,
-        # the PR-70 modules returns 5 more bytes, however:
-        'firmware_date':      (None, '8x4x2x2x2x26s'),
+        'firmware_version':   (None, '8x4xH2x2x21x5x'),
+        'protocol_version':   (None, '8x4x2xH2x21x5x'),
+        'hardware_version':   (None, '8x4x2x2xH21x5x'),
+        'firmware_date':      (None, '8x4x2x2x2x21s5x'),
+        # Note: There are 5 more bytes which the Schunk manual doesn't mention.
+        # The meaning of these mysterious bytes is not known.
+        '_internal':          (None, '8x4x2x2x2x21x5s'),
     }
 
     def __init__(self, module):
@@ -707,16 +708,16 @@ def coroutine(func):
     return start
 
 
-class RS232Connection:
+class SerialConnection:
 
-    """A serial connection using RS232.
+    """A serial connection.
 
     For further documentation see the __init__() docstring.
 
     """
 
     def __init__(self, id, serialmanager, *args, **kwargs):
-        """Prepare a serial connection using the RS232 protocol.
+        """Prepare a serial connection.
 
         This can be used to initialize a :class:`Module`.
 
@@ -760,8 +761,8 @@ class RS232Connection:
         Using PySerial_:
 
         >>> import serial
-        >>> conn = RS232Connection(0x0B, serial.Serial, port=0,
-        ...                        baudrate=9600, timeout=1)
+        >>> conn = SerialConnection(0x0B, serial.Serial, port=0,
+        ...                         baudrate=9600, timeout=1)
 
         """
         self._id = id
@@ -771,12 +772,12 @@ class RS232Connection:
 
     @coroutine
     def open(self):
-        """Open an RS232 connection.
+        """Open a serial connection.
 
         A coroutine (a.k.a. generator object) is returned which can be
         used to send and receive one or more data frames.
 
-        Calling ``.send(data)`` on this coroutine creates an RS232 frame
+        Calling ``.send(data)`` on this coroutine creates a serial frame
         around `data`, sends it to the module and waits for a response.
 
         `data` must have at least two bytes, D-Len and command code.
@@ -803,7 +804,7 @@ class RS232Connection:
             Response data received from the module, including D-Len and
             command code.
 
-            If the first RS232 byte indicates an error (0x03), the
+            If the first byte indicates an error (0x03), the
             response is returned normally and the error has to be
             handled in the calling function. Error responses always have
             a D-Len of 2, i.e. they have 3 bytes: D-Len, command code
@@ -825,33 +826,33 @@ class RS232Connection:
                     next_msg = struct.pack('BB', 0x05, self._id) + next_msg
                     next_msg += crc16(next_msg)
                     if serial.write(next_msg) != len(next_msg):
-                        raise SchunkRS232Error("Error sending data")
+                        raise SchunkSerialError("Error sending data")
 
                 header = serial.read(3)
                 if len(header) < 3:
-                    raise SchunkRS232Error("Error reading response")
+                    raise SchunkSerialError("Error reading response")
 
                 msg_type, module_id, dlen = header
                 if module_id != self._id:
-                    raise SchunkRS232Error("Module ID mismatch")
+                    raise SchunkSerialError("Module ID mismatch")
                 elif msg_type not in (0x03, 0x07):
-                    raise SchunkRS232Error(
+                    raise SchunkSerialError(
                         "Unexpected message type in response: "
                         "0x{:02X}".format(msg_type))
                 crclen = 2
                 the_rest = serial.read(dlen + crclen)
 
                 if len(the_rest) < dlen + crclen:
-                    raise SchunkRS232Error("Not enough data in response")
+                    raise SchunkSerialError("Not enough data in response")
 
                 crc = the_rest[-crclen:]
                 the_rest = the_rest[:-crclen]
                 if crc != crc16(header + the_rest):
-                    raise SchunkRS232Error("CRC error in response")
+                    raise SchunkSerialError("CRC error in response")
 
                 if msg_type == 0x03 and dlen != 2:
                     # This should never happen, but who knows ...
-                    raise SchunkRS232Error(
+                    raise SchunkSerialError(
                         "Message type 0x03, D-Len {}, data: {}".format(
                             dlen, the_rest))
 
@@ -860,15 +861,15 @@ class RS232Connection:
                 response = struct.pack('B', dlen) + the_rest
 
 
-class SchunkRS232Error(SchunkError):
-    """Exception class for errors related to RS232 connections.
+class SchunkSerialError(SchunkError):
+    """Exception class for errors related to serial connections.
 
     It is derived from :exc:`SchunkError`, so it is normally
     sufficient to check only for this::
 
         try:
             ...
-            # Something that may throw SchunkError or SchunkRS232Error
+            # Something that may throw SchunkError or SchunkSerialError
             ...
         except SchunkError as e:
             # Do something with e
@@ -989,10 +990,10 @@ _crc16_tbl = [
 
 communication_modes = {
     0x00: 'AUTO',
-    0x01: 'RS232',
+    0x01: 'serial',
     0x02: 'CAN',
     0x03: 'Profibus DPV0',
-    0x04: 'RS232 Silent',
+    0x04: 'serial silent',
 }
 """Available communication modes.
 
@@ -1003,14 +1004,14 @@ See :attr:`Module.config`.
 unit_systems = {
     0x00: '[mm]',
     0x01: '[m]',
-    0x02: '[Inch]',
+    0x02: '[inches]',
     0x03: '[rad]',
-    0x04: '[Degree]',
-    0x05: '[Intern]',
+    0x04: '[degrees]',
+    0x05: '[internal]',
     0x06: '[µm] Integer',
-    0x07: '[µDegree] Integer',
-    0x08: '[µInch] Integer',
-    0x09: '[Milli - degree] Integer',
+    0x07: '[µdegrees] Integer',
+    0x08: '[µinches] Integer',
+    0x09: '[millidegrees] Integer',
 }
 """Available unit systems.
 
@@ -1057,7 +1058,7 @@ error_codes = {
     0xEC: "ERROR MATH",
     0xDB: "ERROR VPC3",
     0xDC: "ERROR FRAGMENTATION",
-    0xE4: "ERROR COMMUTATION",
+    0xDD: "ERROR COMMUTATION",
     0xDE: "ERROR CURRENT",
     0xDF: "ERROR I2T",
     0xE0: "ERROR INITIALIZE",
@@ -1077,8 +1078,6 @@ error_codes = {
 
 See also :meth:`Module.get_state`.
 
-.. note:: Error in Schunk manual: key 0xE4 (= 228) is not unique!
-
 """
 
 # The Schunk people chose -1.2345 and 47.11 as test values which is
